@@ -1,17 +1,26 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 # Copyright, 2019, by Bryan Powell.
 # Copyright, 2020, by Michael Adams.
 # Copyright, 2021, by Robert Schulze.
 
-require_relative 'buffer'
-
 module Console
-	UNKNOWN = 'unknown'
+	UNKNOWN = :unknown
 	
 	class Filter
+		if Object.const_defined?(:Ractor) and RUBY_VERSION >= '3.1'
+			def self.define_immutable_method(name, &block)
+				block = Ractor.make_shareable(block)
+				self.define_method(name, &block)
+			end
+		else
+			def self.define_immutable_method(name, &block)
+				define_method(name, &block)
+			end
+		end
+		
 		def self.[] **levels
 			klass = Class.new(self)
 			minimum_level, maximum_level = levels.values.minmax
@@ -24,17 +33,17 @@ module Console
 				levels.each do |name, level|
 					const_set(name.to_s.upcase, level)
 					
-					define_method(name) do |subject = nil, *arguments, **options, &block|
+					define_immutable_method(name) do |subject = nil, *arguments, **options, &block|
 						if self.enabled?(subject, level)
-							self.call(subject, *arguments, severity: name, **options, **@options, &block)
+							@output.call(subject, *arguments, severity: name, **@options, **options, &block)
 						end
 					end
 					
-					define_method("#{name}!") do
+					define_immutable_method("#{name}!") do
 						@level = level
 					end
 					
-					define_method("#{name}?") do
+					define_immutable_method("#{name}?") do
 						@level <= level
 					end
 				end
@@ -134,8 +143,13 @@ module Console
 			@subjects.delete(subject)
 		end
 		
-		def call(*arguments, **options, &block)
-			@output.call(*arguments, **options, &block)
+		def call(subject, *arguments, **options, &block)
+			severity = options[:severity] || UNKNOWN
+			level = self.class::LEVELS[severity]
+			
+			if self.enabled?(subject, level)
+				@output.call(subject, *arguments, **options, &block)
+			end
 		end
 	end
 end
